@@ -72,11 +72,11 @@ _OptionalAgentConfigurationTypeDef = TypedDict(
     {
         "agentParameters": Dict[
             Literal[
-                "MaxStackDepth",
-                "MemoryUsageLimitPercent",
-                "MinimumTimeForReportingInMilliseconds",
-                "ReportingIntervalInMilliseconds",
                 "SamplingIntervalInMilliseconds",
+                "ReportingIntervalInMilliseconds",
+                "MinimumTimeForReportingInMilliseconds",
+                "MemoryUsageLimitPercent",
+                "MaxStackDepth",
             ],
             str,
         ]
@@ -97,7 +97,7 @@ AgentOrchestrationConfigTypeDef = TypedDict(
 
 AggregatedProfileTimeTypeDef = TypedDict(
     "AggregatedProfileTimeTypeDef",
-    {"period": Literal["P1D", "PT1H", "PT5M"], "start": datetime},
+    {"period": Literal["PT5M", "PT1H", "P1D"], "start": datetime},
     total=False,
 )
 
@@ -187,7 +187,7 @@ ProfilingGroupDescriptionTypeDef = TypedDict(
     {
         "agentOrchestrationConfig": "AgentOrchestrationConfigTypeDef",
         "arn": str,
-        "computePlatform": Literal["AWSLambda", "Default"],
+        "computePlatform": Literal["Default", "AWSLambda"],
         "createdAt": datetime,
         "name": str,
         "profilingStatus": "ProfilingStatusTypeDef",
@@ -221,7 +221,7 @@ RecommendationTypeDef = TypedDict(
 
 TimestampStructureTypeDef = TypedDict("TimestampStructureTypeDef", {"value": datetime})
 
-UserFeedbackTypeDef = TypedDict("UserFeedbackTypeDef", {"type": Literal["Negative", "Positive"]})
+UserFeedbackTypeDef = TypedDict("UserFeedbackTypeDef", {"type": Literal["Positive", "Negative"]})
 
 AddNotificationChannelsResponseTypeDef = TypedDict(
     "AddNotificationChannelsResponseTypeDef",
@@ -235,7 +235,7 @@ BatchGetFrameMetricDataResponseTypeDef = TypedDict(
         "endTime": datetime,
         "endTimes": List["TimestampStructureTypeDef"],
         "frameMetricData": List["FrameMetricDatumTypeDef"],
-        "resolution": Literal["P1D", "PT1H", "PT5M"],
+        "resolution": Literal["PT5M", "PT1H", "P1D"],
         "startTime": datetime,
         "unprocessedEndTimes": Dict[str, List["TimestampStructureTypeDef"]],
     },
